=============
Release Notes
=============

This section documents the changes that have been made in various versions
of Diofant.  Users should consult these pages to learn about new features,
bug fixes and backwards incompatibilities.  Developers should summarize the
development work they do here in a user friendly format.

.. toctree::
   :glob:
   :maxdepth: 1
   :reversed:

   sympy
   notes-0.[89]*
   notes-0.1[01]*
